from genericpath import isfile
import pkg_resources
import os
import configparser

from .binubuo import binubuo
from .BinubuoTemplate import BinubuoTemplate

config_exists = False
config_location = "In house"

# Check if we have configuration somewhere else than home directory
if "BINUBUO_HOME" in os.environ:
    # Look for config file here
    if os.path.isfile(os.environ["BINUBUO_HOME"] + "\\binubuo.conf"):
        config_location = os.environ["BINUBUO_HOME"] + "\\binubuo.conf"
        config_exists = True
elif "HOME" in os.environ:
    if os.path.isfile(os.environ["HOME"] + "\\binubuo.conf"):
    # Check for config file in users HOME
        config_location = os.environ["HOME"] + "\\binubuo.conf"
        config_exists = True
elif os.path.isfile(os.getcwd() + "\\binubuo.conf"):
    # Check for config file in current directory
    config_location = os.getcwd() + "\\binubuo.conf"
    config_exists = True
else:
    # No config file exists, just set defaults if needed
    binubuo_config = configparser.ConfigParser()
    binubuo_config['OUTPUTS'] = {'dependency_warnings': 'yes'}

if config_exists:
    binubuo_config = configparser.ConfigParser()
    binubuo_config.read(config_location)

# Get packages available for us. We need to check if the pre-requisites for the different database
# options are available when importing them.
pkgs_installed = {pkg.key for pkg in pkg_resources.working_set}

# Oracle requirements
oracle_required = {'cx-oracle'}
oracle_missing = oracle_required - pkgs_installed

if oracle_missing:
    if binubuo_config['OUTPUTS']['dependency_warnings'] == 'yes':
        print("Oracle client not installed. Please install cx_Oracle for Oracle support.")
else:
    from .binubuoOracle import binubuoOracle

# Postgres requirements
postgres_required = {'psycopg2'}
postgres_missing = postgres_required - pkgs_installed

if postgres_missing:
    # Check for binary also
    postgres_bin_required = {'psycopg2-binary'}
    postgres_bin_missing = postgres_bin_required - pkgs_installed
    if postgres_bin_missing:
        if binubuo_config['OUTPUTS']['dependency_warnings'] == 'yes':
            print("Postgres client not installed. Please install Psycopg2 for Postgres support.")
    else:
        from .binubuoPostgres import binubuoPostgres
else:
    from .binubuoPostgres import binubuoPostgres

# yugabyte requirements
yugabyte_required = {'psycopg2'}
yugabyte_missing = yugabyte_required - pkgs_installed

if yugabyte_missing:
    # Check for binary also
    yugabyte_bin_required = {'psycopg2-binary'}
    yugabyte_bin_missing = yugabyte_bin_required - pkgs_installed
    if yugabyte_bin_missing:
        if binubuo_config['OUTPUTS']['dependency_warnings'] == 'yes':
            print("yugabyte client not installed. Please install Psycopg2 for YugabyteDB support.")
    else:
        from .binubuoYugabyte import binubuoYugabyte
else:
    from .binubuoYugabyte import binubuoYugabyte

# SQL Server requirements
sqlserver_required = {'pyodbc'}
sqlserver_missing = sqlserver_required - pkgs_installed

if sqlserver_missing:
    if binubuo_config['OUTPUTS']['dependency_warnings'] == 'yes':
        print("SQL Server client not installed. Please install pyodbc for SQL Server support.")
else:
    from .binubuoSQLServer import binubuoSQLServer